/// <reference types="node" />
import http from 'http';
import { Employee } from '../model/employee';
import { EmployeeEndpointRequest } from '../model/employeeEndpointRequest';
import { EmployeeResponse } from '../model/employeeResponse';
import { IgnoreCommonModel } from '../model/ignoreCommonModel';
import { IgnoreCommonModelRequest } from '../model/ignoreCommonModelRequest';
import { MetaResponse } from '../model/metaResponse';
import { PaginatedEmployeeList } from '../model/paginatedEmployeeList';
import { Authentication, Interceptor } from '../model/models';
import { ApiKeyAuth } from '../model/models';
export declare enum EmployeesApiApiKeys {
    tokenAuth = 0
}
export declare class EmployeesApi {
    protected _basePath: string;
    protected _defaultHeaders: any;
    protected _useQuerystring: boolean;
    protected authentications: {
        default: Authentication;
        tokenAuth: ApiKeyAuth;
    };
    protected interceptors: Interceptor[];
    constructor(basePath?: string);
    set useQuerystring(value: boolean);
    set basePath(basePath: string);
    set defaultHeaders(defaultHeaders: any);
    get defaultHeaders(): any;
    get basePath(): string;
    setDefaultAuthentication(auth: Authentication): void;
    setApiKey(key: EmployeesApiApiKeys, value: string): void;
    addInterceptor(interceptor: Interceptor): void;
    employeesCreate(xAccountToken: string, employeeEndpointRequest: EmployeeEndpointRequest, isDebugMode?: boolean, runAsync?: boolean, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.IncomingMessage;
        body: EmployeeResponse;
    }>;
    employeesIgnoreCreate(xAccountToken: string, modelId: string, ignoreCommonModelRequest: IgnoreCommonModelRequest, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.IncomingMessage;
        body: IgnoreCommonModel;
    }>;
    employeesList(xAccountToken: string, companyId?: string, createdAfter?: Date, createdBefore?: Date, cursor?: string, displayFullName?: string, employmentStatus?: 'ACTIVE' | 'INACTIVE' | 'PENDING', expand?: 'company' | 'company,pay_group' | 'employments' | 'employments,company' | 'employments,company,pay_group' | 'employments,groups' | 'employments,groups,company' | 'employments,groups,company,pay_group' | 'employments,groups,home_location' | 'employments,groups,home_location,company' | 'employments,groups,home_location,company,pay_group' | 'employments,groups,home_location,manager' | 'employments,groups,home_location,manager,company' | 'employments,groups,home_location,manager,company,pay_group' | 'employments,groups,home_location,manager,pay_group' | 'employments,groups,home_location,manager,team' | 'employments,groups,home_location,manager,team,company' | 'employments,groups,home_location,manager,team,company,pay_group' | 'employments,groups,home_location,manager,team,pay_group' | 'employments,groups,home_location,pay_group' | 'employments,groups,home_location,team' | 'employments,groups,home_location,team,company' | 'employments,groups,home_location,team,company,pay_group' | 'employments,groups,home_location,team,pay_group' | 'employments,groups,home_location,work_location' | 'employments,groups,home_location,work_location,company' | 'employments,groups,home_location,work_location,company,pay_group' | 'employments,groups,home_location,work_location,manager' | 'employments,groups,home_location,work_location,manager,company' | 'employments,groups,home_location,work_location,manager,company,pay_group' | 'employments,groups,home_location,work_location,manager,pay_group' | 'employments,groups,home_location,work_location,manager,team' | 'employments,groups,home_location,work_location,manager,team,company' | 'employments,groups,home_location,work_location,manager,team,company,pay_group' | 'employments,groups,home_location,work_location,manager,team,pay_group' | 'employments,groups,home_location,work_location,pay_group' | 'employments,groups,home_location,work_location,team' | 'employments,groups,home_location,work_location,team,company' | 'employments,groups,home_location,work_location,team,company,pay_group' | 'employments,groups,home_location,work_location,team,pay_group' | 'employments,groups,manager' | 'employments,groups,manager,company' | 'employments,groups,manager,company,pay_group' | 'employments,groups,manager,pay_group' | 'employments,groups,manager,team' | 'employments,groups,manager,team,company' | 'employments,groups,manager,team,company,pay_group' | 'employments,groups,manager,team,pay_group' | 'employments,groups,pay_group' | 'employments,groups,team' | 'employments,groups,team,company' | 'employments,groups,team,company,pay_group' | 'employments,groups,team,pay_group' | 'employments,groups,work_location' | 'employments,groups,work_location,company' | 'employments,groups,work_location,company,pay_group' | 'employments,groups,work_location,manager' | 'employments,groups,work_location,manager,company' | 'employments,groups,work_location,manager,company,pay_group' | 'employments,groups,work_location,manager,pay_group' | 'employments,groups,work_location,manager,team' | 'employments,groups,work_location,manager,team,company' | 'employments,groups,work_location,manager,team,company,pay_group' | 'employments,groups,work_location,manager,team,pay_group' | 'employments,groups,work_location,pay_group' | 'employments,groups,work_location,team' | 'employments,groups,work_location,team,company' | 'employments,groups,work_location,team,company,pay_group' | 'employments,groups,work_location,team,pay_group' | 'employments,home_location' | 'employments,home_location,company' | 'employments,home_location,company,pay_group' | 'employments,home_location,manager' | 'employments,home_location,manager,company' | 'employments,home_location,manager,company,pay_group' | 'employments,home_location,manager,pay_group' | 'employments,home_location,manager,team' | 'employments,home_location,manager,team,company' | 'employments,home_location,manager,team,company,pay_group' | 'employments,home_location,manager,team,pay_group' | 'employments,home_location,pay_group' | 'employments,home_location,team' | 'employments,home_location,team,company' | 'employments,home_location,team,company,pay_group' | 'employments,home_location,team,pay_group' | 'employments,home_location,work_location' | 'employments,home_location,work_location,company' | 'employments,home_location,work_location,company,pay_group' | 'employments,home_location,work_location,manager' | 'employments,home_location,work_location,manager,company' | 'employments,home_location,work_location,manager,company,pay_group' | 'employments,home_location,work_location,manager,pay_group' | 'employments,home_location,work_location,manager,team' | 'employments,home_location,work_location,manager,team,company' | 'employments,home_location,work_location,manager,team,company,pay_group' | 'employments,home_location,work_location,manager,team,pay_group' | 'employments,home_location,work_location,pay_group' | 'employments,home_location,work_location,team' | 'employments,home_location,work_location,team,company' | 'employments,home_location,work_location,team,company,pay_group' | 'employments,home_location,work_location,team,pay_group' | 'employments,manager' | 'employments,manager,company' | 'employments,manager,company,pay_group' | 'employments,manager,pay_group' | 'employments,manager,team' | 'employments,manager,team,company' | 'employments,manager,team,company,pay_group' | 'employments,manager,team,pay_group' | 'employments,pay_group' | 'employments,team' | 'employments,team,company' | 'employments,team,company,pay_group' | 'employments,team,pay_group' | 'employments,work_location' | 'employments,work_location,company' | 'employments,work_location,company,pay_group' | 'employments,work_location,manager' | 'employments,work_location,manager,company' | 'employments,work_location,manager,company,pay_group' | 'employments,work_location,manager,pay_group' | 'employments,work_location,manager,team' | 'employments,work_location,manager,team,company' | 'employments,work_location,manager,team,company,pay_group' | 'employments,work_location,manager,team,pay_group' | 'employments,work_location,pay_group' | 'employments,work_location,team' | 'employments,work_location,team,company' | 'employments,work_location,team,company,pay_group' | 'employments,work_location,team,pay_group' | 'groups' | 'groups,company' | 'groups,company,pay_group' | 'groups,home_location' | 'groups,home_location,company' | 'groups,home_location,company,pay_group' | 'groups,home_location,manager' | 'groups,home_location,manager,company' | 'groups,home_location,manager,company,pay_group' | 'groups,home_location,manager,pay_group' | 'groups,home_location,manager,team' | 'groups,home_location,manager,team,company' | 'groups,home_location,manager,team,company,pay_group' | 'groups,home_location,manager,team,pay_group' | 'groups,home_location,pay_group' | 'groups,home_location,team' | 'groups,home_location,team,company' | 'groups,home_location,team,company,pay_group' | 'groups,home_location,team,pay_group' | 'groups,home_location,work_location' | 'groups,home_location,work_location,company' | 'groups,home_location,work_location,company,pay_group' | 'groups,home_location,work_location,manager' | 'groups,home_location,work_location,manager,company' | 'groups,home_location,work_location,manager,company,pay_group' | 'groups,home_location,work_location,manager,pay_group' | 'groups,home_location,work_location,manager,team' | 'groups,home_location,work_location,manager,team,company' | 'groups,home_location,work_location,manager,team,company,pay_group' | 'groups,home_location,work_location,manager,team,pay_group' | 'groups,home_location,work_location,pay_group' | 'groups,home_location,work_location,team' | 'groups,home_location,work_location,team,company' | 'groups,home_location,work_location,team,company,pay_group' | 'groups,home_location,work_location,team,pay_group' | 'groups,manager' | 'groups,manager,company' | 'groups,manager,company,pay_group' | 'groups,manager,pay_group' | 'groups,manager,team' | 'groups,manager,team,company' | 'groups,manager,team,company,pay_group' | 'groups,manager,team,pay_group' | 'groups,pay_group' | 'groups,team' | 'groups,team,company' | 'groups,team,company,pay_group' | 'groups,team,pay_group' | 'groups,work_location' | 'groups,work_location,company' | 'groups,work_location,company,pay_group' | 'groups,work_location,manager' | 'groups,work_location,manager,company' | 'groups,work_location,manager,company,pay_group' | 'groups,work_location,manager,pay_group' | 'groups,work_location,manager,team' | 'groups,work_location,manager,team,company' | 'groups,work_location,manager,team,company,pay_group' | 'groups,work_location,manager,team,pay_group' | 'groups,work_location,pay_group' | 'groups,work_location,team' | 'groups,work_location,team,company' | 'groups,work_location,team,company,pay_group' | 'groups,work_location,team,pay_group' | 'home_location' | 'home_location,company' | 'home_location,company,pay_group' | 'home_location,manager' | 'home_location,manager,company' | 'home_location,manager,company,pay_group' | 'home_location,manager,pay_group' | 'home_location,manager,team' | 'home_location,manager,team,company' | 'home_location,manager,team,company,pay_group' | 'home_location,manager,team,pay_group' | 'home_location,pay_group' | 'home_location,team' | 'home_location,team,company' | 'home_location,team,company,pay_group' | 'home_location,team,pay_group' | 'home_location,work_location' | 'home_location,work_location,company' | 'home_location,work_location,company,pay_group' | 'home_location,work_location,manager' | 'home_location,work_location,manager,company' | 'home_location,work_location,manager,company,pay_group' | 'home_location,work_location,manager,pay_group' | 'home_location,work_location,manager,team' | 'home_location,work_location,manager,team,company' | 'home_location,work_location,manager,team,company,pay_group' | 'home_location,work_location,manager,team,pay_group' | 'home_location,work_location,pay_group' | 'home_location,work_location,team' | 'home_location,work_location,team,company' | 'home_location,work_location,team,company,pay_group' | 'home_location,work_location,team,pay_group' | 'manager' | 'manager,company' | 'manager,company,pay_group' | 'manager,pay_group' | 'manager,team' | 'manager,team,company' | 'manager,team,company,pay_group' | 'manager,team,pay_group' | 'pay_group' | 'team' | 'team,company' | 'team,company,pay_group' | 'team,pay_group' | 'work_location' | 'work_location,company' | 'work_location,company,pay_group' | 'work_location,manager' | 'work_location,manager,company' | 'work_location,manager,company,pay_group' | 'work_location,manager,pay_group' | 'work_location,manager,team' | 'work_location,manager,team,company' | 'work_location,manager,team,company,pay_group' | 'work_location,manager,team,pay_group' | 'work_location,pay_group' | 'work_location,team' | 'work_location,team,company' | 'work_location,team,company,pay_group' | 'work_location,team,pay_group', firstName?: string, includeDeletedData?: boolean, includeRemoteData?: boolean, includeSensitiveFields?: boolean, lastName?: string, managerId?: string, modifiedAfter?: Date, modifiedBefore?: Date, pageSize?: number, payGroupId?: string, personalEmail?: string, remoteId?: string, teamId?: string, workEmail?: string, workLocationId?: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.IncomingMessage;
        body: PaginatedEmployeeList;
    }>;
    employeesMetaPostRetrieve(xAccountToken: string, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.IncomingMessage;
        body: MetaResponse;
    }>;
    employeesRetrieve(xAccountToken: string, id: string, expand?: 'company' | 'company,pay_group' | 'employments' | 'employments,company' | 'employments,company,pay_group' | 'employments,groups' | 'employments,groups,company' | 'employments,groups,company,pay_group' | 'employments,groups,home_location' | 'employments,groups,home_location,company' | 'employments,groups,home_location,company,pay_group' | 'employments,groups,home_location,manager' | 'employments,groups,home_location,manager,company' | 'employments,groups,home_location,manager,company,pay_group' | 'employments,groups,home_location,manager,pay_group' | 'employments,groups,home_location,manager,team' | 'employments,groups,home_location,manager,team,company' | 'employments,groups,home_location,manager,team,company,pay_group' | 'employments,groups,home_location,manager,team,pay_group' | 'employments,groups,home_location,pay_group' | 'employments,groups,home_location,team' | 'employments,groups,home_location,team,company' | 'employments,groups,home_location,team,company,pay_group' | 'employments,groups,home_location,team,pay_group' | 'employments,groups,home_location,work_location' | 'employments,groups,home_location,work_location,company' | 'employments,groups,home_location,work_location,company,pay_group' | 'employments,groups,home_location,work_location,manager' | 'employments,groups,home_location,work_location,manager,company' | 'employments,groups,home_location,work_location,manager,company,pay_group' | 'employments,groups,home_location,work_location,manager,pay_group' | 'employments,groups,home_location,work_location,manager,team' | 'employments,groups,home_location,work_location,manager,team,company' | 'employments,groups,home_location,work_location,manager,team,company,pay_group' | 'employments,groups,home_location,work_location,manager,team,pay_group' | 'employments,groups,home_location,work_location,pay_group' | 'employments,groups,home_location,work_location,team' | 'employments,groups,home_location,work_location,team,company' | 'employments,groups,home_location,work_location,team,company,pay_group' | 'employments,groups,home_location,work_location,team,pay_group' | 'employments,groups,manager' | 'employments,groups,manager,company' | 'employments,groups,manager,company,pay_group' | 'employments,groups,manager,pay_group' | 'employments,groups,manager,team' | 'employments,groups,manager,team,company' | 'employments,groups,manager,team,company,pay_group' | 'employments,groups,manager,team,pay_group' | 'employments,groups,pay_group' | 'employments,groups,team' | 'employments,groups,team,company' | 'employments,groups,team,company,pay_group' | 'employments,groups,team,pay_group' | 'employments,groups,work_location' | 'employments,groups,work_location,company' | 'employments,groups,work_location,company,pay_group' | 'employments,groups,work_location,manager' | 'employments,groups,work_location,manager,company' | 'employments,groups,work_location,manager,company,pay_group' | 'employments,groups,work_location,manager,pay_group' | 'employments,groups,work_location,manager,team' | 'employments,groups,work_location,manager,team,company' | 'employments,groups,work_location,manager,team,company,pay_group' | 'employments,groups,work_location,manager,team,pay_group' | 'employments,groups,work_location,pay_group' | 'employments,groups,work_location,team' | 'employments,groups,work_location,team,company' | 'employments,groups,work_location,team,company,pay_group' | 'employments,groups,work_location,team,pay_group' | 'employments,home_location' | 'employments,home_location,company' | 'employments,home_location,company,pay_group' | 'employments,home_location,manager' | 'employments,home_location,manager,company' | 'employments,home_location,manager,company,pay_group' | 'employments,home_location,manager,pay_group' | 'employments,home_location,manager,team' | 'employments,home_location,manager,team,company' | 'employments,home_location,manager,team,company,pay_group' | 'employments,home_location,manager,team,pay_group' | 'employments,home_location,pay_group' | 'employments,home_location,team' | 'employments,home_location,team,company' | 'employments,home_location,team,company,pay_group' | 'employments,home_location,team,pay_group' | 'employments,home_location,work_location' | 'employments,home_location,work_location,company' | 'employments,home_location,work_location,company,pay_group' | 'employments,home_location,work_location,manager' | 'employments,home_location,work_location,manager,company' | 'employments,home_location,work_location,manager,company,pay_group' | 'employments,home_location,work_location,manager,pay_group' | 'employments,home_location,work_location,manager,team' | 'employments,home_location,work_location,manager,team,company' | 'employments,home_location,work_location,manager,team,company,pay_group' | 'employments,home_location,work_location,manager,team,pay_group' | 'employments,home_location,work_location,pay_group' | 'employments,home_location,work_location,team' | 'employments,home_location,work_location,team,company' | 'employments,home_location,work_location,team,company,pay_group' | 'employments,home_location,work_location,team,pay_group' | 'employments,manager' | 'employments,manager,company' | 'employments,manager,company,pay_group' | 'employments,manager,pay_group' | 'employments,manager,team' | 'employments,manager,team,company' | 'employments,manager,team,company,pay_group' | 'employments,manager,team,pay_group' | 'employments,pay_group' | 'employments,team' | 'employments,team,company' | 'employments,team,company,pay_group' | 'employments,team,pay_group' | 'employments,work_location' | 'employments,work_location,company' | 'employments,work_location,company,pay_group' | 'employments,work_location,manager' | 'employments,work_location,manager,company' | 'employments,work_location,manager,company,pay_group' | 'employments,work_location,manager,pay_group' | 'employments,work_location,manager,team' | 'employments,work_location,manager,team,company' | 'employments,work_location,manager,team,company,pay_group' | 'employments,work_location,manager,team,pay_group' | 'employments,work_location,pay_group' | 'employments,work_location,team' | 'employments,work_location,team,company' | 'employments,work_location,team,company,pay_group' | 'employments,work_location,team,pay_group' | 'groups' | 'groups,company' | 'groups,company,pay_group' | 'groups,home_location' | 'groups,home_location,company' | 'groups,home_location,company,pay_group' | 'groups,home_location,manager' | 'groups,home_location,manager,company' | 'groups,home_location,manager,company,pay_group' | 'groups,home_location,manager,pay_group' | 'groups,home_location,manager,team' | 'groups,home_location,manager,team,company' | 'groups,home_location,manager,team,company,pay_group' | 'groups,home_location,manager,team,pay_group' | 'groups,home_location,pay_group' | 'groups,home_location,team' | 'groups,home_location,team,company' | 'groups,home_location,team,company,pay_group' | 'groups,home_location,team,pay_group' | 'groups,home_location,work_location' | 'groups,home_location,work_location,company' | 'groups,home_location,work_location,company,pay_group' | 'groups,home_location,work_location,manager' | 'groups,home_location,work_location,manager,company' | 'groups,home_location,work_location,manager,company,pay_group' | 'groups,home_location,work_location,manager,pay_group' | 'groups,home_location,work_location,manager,team' | 'groups,home_location,work_location,manager,team,company' | 'groups,home_location,work_location,manager,team,company,pay_group' | 'groups,home_location,work_location,manager,team,pay_group' | 'groups,home_location,work_location,pay_group' | 'groups,home_location,work_location,team' | 'groups,home_location,work_location,team,company' | 'groups,home_location,work_location,team,company,pay_group' | 'groups,home_location,work_location,team,pay_group' | 'groups,manager' | 'groups,manager,company' | 'groups,manager,company,pay_group' | 'groups,manager,pay_group' | 'groups,manager,team' | 'groups,manager,team,company' | 'groups,manager,team,company,pay_group' | 'groups,manager,team,pay_group' | 'groups,pay_group' | 'groups,team' | 'groups,team,company' | 'groups,team,company,pay_group' | 'groups,team,pay_group' | 'groups,work_location' | 'groups,work_location,company' | 'groups,work_location,company,pay_group' | 'groups,work_location,manager' | 'groups,work_location,manager,company' | 'groups,work_location,manager,company,pay_group' | 'groups,work_location,manager,pay_group' | 'groups,work_location,manager,team' | 'groups,work_location,manager,team,company' | 'groups,work_location,manager,team,company,pay_group' | 'groups,work_location,manager,team,pay_group' | 'groups,work_location,pay_group' | 'groups,work_location,team' | 'groups,work_location,team,company' | 'groups,work_location,team,company,pay_group' | 'groups,work_location,team,pay_group' | 'home_location' | 'home_location,company' | 'home_location,company,pay_group' | 'home_location,manager' | 'home_location,manager,company' | 'home_location,manager,company,pay_group' | 'home_location,manager,pay_group' | 'home_location,manager,team' | 'home_location,manager,team,company' | 'home_location,manager,team,company,pay_group' | 'home_location,manager,team,pay_group' | 'home_location,pay_group' | 'home_location,team' | 'home_location,team,company' | 'home_location,team,company,pay_group' | 'home_location,team,pay_group' | 'home_location,work_location' | 'home_location,work_location,company' | 'home_location,work_location,company,pay_group' | 'home_location,work_location,manager' | 'home_location,work_location,manager,company' | 'home_location,work_location,manager,company,pay_group' | 'home_location,work_location,manager,pay_group' | 'home_location,work_location,manager,team' | 'home_location,work_location,manager,team,company' | 'home_location,work_location,manager,team,company,pay_group' | 'home_location,work_location,manager,team,pay_group' | 'home_location,work_location,pay_group' | 'home_location,work_location,team' | 'home_location,work_location,team,company' | 'home_location,work_location,team,company,pay_group' | 'home_location,work_location,team,pay_group' | 'manager' | 'manager,company' | 'manager,company,pay_group' | 'manager,pay_group' | 'manager,team' | 'manager,team,company' | 'manager,team,company,pay_group' | 'manager,team,pay_group' | 'pay_group' | 'team' | 'team,company' | 'team,company,pay_group' | 'team,pay_group' | 'work_location' | 'work_location,company' | 'work_location,company,pay_group' | 'work_location,manager' | 'work_location,manager,company' | 'work_location,manager,company,pay_group' | 'work_location,manager,pay_group' | 'work_location,manager,team' | 'work_location,manager,team,company' | 'work_location,manager,team,company,pay_group' | 'work_location,manager,team,pay_group' | 'work_location,pay_group' | 'work_location,team' | 'work_location,team,company' | 'work_location,team,company,pay_group' | 'work_location,team,pay_group', includeRemoteData?: boolean, includeSensitiveFields?: boolean, options?: {
        headers: {
            [name: string]: string;
        };
    }): Promise<{
        response: http.IncomingMessage;
        body: Employee;
    }>;
}
